@@ -28,7 +28,9 @@ class Imaging:
             "GetImagingSettings", VideoSourceToken=VideoSourceToken
         )
 
-    def SetImagingSettings(self, VideoSourceToken, ImagingSettings, ForcePersistence=None):
+    def SetImagingSettings(
+        self, VideoSourceToken, ImagingSettings, ForcePersistence=None
+    ):
         return self.operator.call(
             "SetImagingSettings",
             VideoSourceToken=VideoSourceToken,
